@@ -12,7 +12,7 @@ use Carp;
 use Data::Table::Text qw(:all);
 use Data::Dump qw(dump);
 
-our $VERSION = '2017.224';
+our $VERSION = '2017.444';
 
 #-------------------------------------------------------------------------------
 # Load speakers
@@ -34,11 +34,19 @@ sub speaker($)
    {for(qw(name gender speaking written country code))
      {Data::Table::Text::genLValueScalarMethods($_);
       package Aws::Polly::Select;
-      eval <<END;
+      eval <<END;                                                               # Possible field values as a string
 sub $_
  {my %l = map {\$_->$_=>1} &speakers;
   join ' ', sort keys %l;
  }
+END
+      $@ and confess $@;
+
+      eval <<END;                                                               # Possible field values as an array
+sub ${_}AsArray
+ {my %l = map {\$_->$_=>1} &speakers;
+  sort keys %l;
+ }
 END
       $@ and confess $@;
      }
